************ WebDownloader pro systém X Window ****************
************ Tento program dosud nemá jméno :(( ***************

Autor:
    Koshelev Maxim 
    e-mail: mdem@chat.ru
    druhý e-mail: chuchelo@krasu.ru
    domácí stránka: http://www.krasu.ru/soft/chuchelo

Hlavní vlastnosti:
    vícevláknový;
    stahování pomocí protokolů HTTP a FTP;
    rekurzivní stahování pomocí protokolů FTP a HTTP;
    změna odkazů v souborech HTML pro prohlížení offline;
    fronta stahování;
    podpora masky;
    podpora FTP a HTTP proxy;
    uživatelsky přátelské grafické rozhraní X Window;
    podpora pokračování souborl po přerušení spojení (užitečné pro vzdálené servery);
    záznamy pro všechna stahování;
    běžný záznam;
    funkce hromadného stahování (stahování jednoho souboru několika vlákny);
    traffic throttle;
    vyhledávání FTP;
    podpora Upusť a Stáhni;

Další vlastnosti:
    mnohem stabilnější než jiné podobné programy pro Linux :))
