*************** WebDownloader dla XWindows ********************
*********** Ten program nie ma jeszcze nazwy :(( **************

Autor:
    Koshelev Maxim 
    e-mail: mdem@chat.ru
    second e-mail: chuchelo@krasu.ru
    home page: http://www.krasu.ru/soft/chuchelo

Główne właściwości:
    wielowątkowość;
    pobieranie poprzez protokoły http i ftp;
    pobieranie rekursywne poprzez protokoły ftp i http;
    kolejkowanie pobierań;
    wsparcie dla maskowania;
    wsparcie dla proxy ftp i http;
    przyjazny dla użytkownika graficzny interfejs pod XWindow;
    wznawianie po przerwaniu połączenia (użyteczne dla odległych miejsc);
    dzienniki dla wszystkich pobierań;
    wspólny dziennik;

Inne właściwości:
    bardziej stabilny niż inne podobne programy dla Linuksa :))
